\name{getyHat_PCR}
\alias{yhat_PCR}
\title{Principal Component and Partial Least Squares Regression Prediction}

\description{
Fits PCR or PLSR to training data and computes the predictions for the test data.
}

\usage{
yhat_PCR(dfTrain, dfTest, ncomp = "default", scaleQ = TRUE,
              ic = c("BIC", "AIC"), alg = c("PCR", "PLSR"))
}

\arguments{
  \item{dfTrain}{Data frame for training data. Last column must be the
  	output variable.}
  \item{dfTest}{Data frame for test data. Last column must be the
        output variable.}
  \item{ncomp}{Maximum number of components. Default is min(n-1, p).}
  \item{scaleQ}{Default is to center and rescale the data so covariance matrix
       has ones on the diagonal.}
  \item{ic}{Information criterion to use to select the number of components.
  		Default is BIC.}
  \item{alg}{Default is PCR (Principal component Regression). Othewise PLSR
  		(Partial Least Squares Regression).}
}

\value{The predictions for the test sample}

\author{A. I. McLeod}

\examples{
\dontrun{#pls is needed
require("pls")
Xy <- prostate
X <- prostate[,-9]
y <- prostate[,9]
n <- length(y)
d <- 10
set.seed(777513)
iTe <- sample(n, size=d)
iTr <- (1:n)[!match(1:n, iTe, nomatch = 0) > 0]
trdf <- data.frame(X[iTr,], y=y[iTr]) #X, y already defined
tedf <- data.frame(X[iTe,], y=y[iTe])
yhat_PCR(trdf, tedf)
}
}

\keyword{ models }
\keyword{ regression }


